<?php
/*
_litebox.plugin.php
:tabSize=2:indentSize=2:noTabs=true:
:folding=explicit:collapseFolds=1:

Copyright (C) 2007 Ian Lewis (IanLewis@member.fsf.org)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
Optionally, you may find a copy of the GNU General Public License
from http://www.fsf.org/copyleft/gpl.txt
*/

if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * A plugin that implements adding images that can be opened by litebox into
 * a blog entry.
 * @author Ian Lewis (<a href="mailto:IanLewis@member.fsf.org">IanLewis@member.fsf.org</a>)
 */
class lightbox_plugin extends Plugin {
  
  var $version = '1.3';
  var $group = 'rendering';
  var $code = 'evo_lightbox';
  var $priority = 50;
  var $author = 'http://www.ianlewis.org/';
  
  //can be overridden
  var $apply_rendering = 'opt-out';
  
  //email search pattern [lightbox <URL> <CAPTION>]<HTML>[/lightbox]
  // var $search = '#\[lightbox (((http|https|ftp):\/\/)?[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(([0-9]{1,5})?\/[^ \[]*)?)([ \t]*\[(.*?)][ \t]*)?](.*?)\[/lightbox]#s';
  var $search = '#\[lightbox (.*?)([ \t]*\[(.*?)][ \t]*)?](.*?)\[/lightbox]#s';
  
  /**
   * Init
   */
  function PluginInit($params ) {
    $this->name = $this->T_('Lightbox');
    $this->short_desc = $this->T_('Allows showing images using Lightbox.');
    $this->long_desc = $this->T_('Allows users to add pictures to their blog and then rendering the item with Lightbox.');
  }
  
  //{{{ GetDefaultSettings()
  /**
   * Returns the settings array for the lightbox plugin
   */
  function GetDefaultSettings() {
    return array('uselightbox2' => array('label' => $this->T_('Use Lightbox2'),
                                         'type' => 'checkbox',
                                         'defaultvalue' => '0',
                                         'note' => $this->T_('If this is checked then use Lightbox2. Changes take effect immediately.'),
                                        )
                 );
  }//}}}
  
  /**
   * Renders the url to the image entered with litebox.
   */
  function RenderItemAsHtml(&$params) {
    $content = & $params['data'];
    
    $replace = "<a href=\"\\1\" rel=\"lightbox\" title=\"\\3\">\\4</a>";
    
    $content = preg_replace($this->search, $replace, $content);
    
    return true;
  }
  
  /**
   * We want to render the text the exact same way in XML as we do in HTML.
   */
  function RenderItemAsXml(&$params) {
    return $this->RenderItemAsHtml($params);
  }
  
  /**
   * Adds the script to the head of the HTML document. The script will decode
   * the email address based on the cypher number. The cypher number is the
   * number to add to the key code for each character when decoding. This is a
   * parameter rather than an arbitrary number so that bots can't simply use
   * the arbitrary number to decode the string (Though they could just try to
   * decode until they find an @ symbol and the number that was used is likely
   * the cypher number. This will be fixed later).
   */
  function SkinBeginHtmlHead(&$params) {
    if ($this->Settings->get('uselightbox2')) {
      print("<link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"".$this->get_plugin_url()."css/lightbox.css\" />\n");
      print("<script language=\"javascript\" type=\"text/javascript\" src=\"".$this->get_plugin_url()."js/prototype.js\"></script>\n");
      print("<script language=\"javascript\" type=\"text/javascript\" src=\"".$this->get_plugin_url()."js/scriptaculous.js?load=effects\"></script>\n");
      print("<script language=\"javascript\" type=\"text/javascript\" src=\"".$this->get_plugin_url()."js/lightbox.js\"></script>\n");
    } else {
      print("<link rel=\"stylesheet\" type=\"text/css\" media=\"screen\" href=\"".$this->get_plugin_url()."lightbox.css\"/>\n");
      print("<script language=\"javascript\" type=\"text/javascript\" src=\"".$this->get_plugin_url()."lightbox.js\"></script>\n");
    }
  }
}

?>
